@@ -21,17 +21,15 @@ from odin.store import Store
 ConfigMap = namedtuple('ConfigMap', 'path name sub_path')
 
 HASH_TRAILING = '-hash'
-CORE_MODULES = [
-    'odin.handlers.job',
-    'odin.handlers.deployment',
-    'odin.handlers.service',
-    'odin.handlers.pod'
-]
+CORE_MODULES = ['odin.handlers.job', 'odin.handlers.deployment', 'odin.handlers.service', 'odin.handlers.pod']
 KF_MODULES = [
     'odin.handlers.mpijob',
     'odin.handlers.tfjob',
     'odin.handlers.pytorchjob',
 ]
+ELASTIC_MODULES = [
+    'odin.handlers.elasticjob',
+]
 DEFAULT_MODULES = CORE_MODULES + KF_MODULES
 REGISTRY = 'registry'
 
